---------------
-- rm area_bernauer_strasse.db ; spatialite area_bernauer_strasse.db < import.area_bernauer_strasse.sql;
-- gdal_translate -a_srs epsg:3068 bernauer_strasse.jpeg bernauer_strasse.tif
---------------
SELECT DateTime('now'),'import.area_bernauer_strasse.sql [start]  ';
---------------------------
BEGIN;
CREATE TABLE berlin_street_segments
(
 id_segment INTEGER PRIMARY KEY,
 id_street INTEGER,
 id_street_segment INTEGER,
 name TEXT DEFAULT '',
 notes TEXT DEFAULT '',
 belongs_to TEXT DEFAULT '',
 admin_level INTEGER DEFAULT 1100,
 valid_since DATE DEFAULT '0001-01-01',
 valid_until DATE DEFAULT '3000-01-01',
 street_class DEFAULT '',
 element_number DEFAULT '',
 meters_length DOUBLE  DEFAULT 0
);
SELECT AddGeometryColumn('berlin_street_segments','soldner_segment',3068,'LINESTRING','XY');
SELECT CreateSpatialIndex('berlin_street_segments','soldner_segment');
---------------
SELECT DateTime('now'),'creating table berlin_polygons';
DROP TABLE IF EXISTS berlin_polygons;
CREATE TABLE berlin_polygons
(
 id_geometry INTEGER PRIMARY KEY,
 id_admin INTEGER DEFAULT 0,
 name TEXT DEFAULT '',
 notes TEXT DEFAULT '',
 admin_level INTEGER DEFAULT 10,
 valid_since DATE DEFAULT '0001-01-01',
 valid_until DATE DEFAULT '3000-01-01',
 changed_type INTEGER DEFAULT 3,
 -- 1=name,2=belongs,3=borders,4=house_numbers
 id_belongs_to INTEGER DEFAULT 0,
 belongs_to TEXT  DEFAULT '',
 -- length of ExteriorRing
 meters_length DOUBLE  DEFAULT 0,
 -- Area of ExteriorRing
 meters_area DOUBLE  DEFAULT 0
);
SELECT AddGeometryColumn('berlin_polygons','soldner_linestring',3068,'MULTILINESTRING','XY');
SELECT CreateSpatialIndex('berlin_polygons','soldner_linestring');
SELECT AddGeometryColumn('berlin_polygons','soldner_polygon',3068,'MULTIPOLYGON','XY');
SELECT CreateSpatialIndex('berlin_polygons','soldner_polygon');
SELECT AddGeometryColumn('berlin_polygons','soldner_ring',3068,'MULTIPOLYGON','XY');
SELECT CreateSpatialIndex('berlin_polygons','soldner_ring');
SELECT AddGeometryColumn('berlin_polygons','soldner_center',3068,'POINT','XY');
SELECT CreateSpatialIndex('berlin_polygons','soldner_center');
COMMIT;
---------------------------
SELECT DateTime('now'),'ATTACH DATABASE ''../berlin_admin_geometries.db'' AS db_import';
ATTACH DATABASE '../../berlin_admin_geometries.db' AS db_import;
---------------------------
BEGIN;
INSERT INTO berlin_street_segments
 (id_segment,id_street,id_street_segment,name,notes,belongs_to,admin_level,valid_since,valid_until,street_class,element_number,meters_length,soldner_segment)
SELECT
 id_segment,
 id_street,
 id_street_segment,
 name,
 notes,
 belongs_to,
 admin_level,
 valid_since,
 valid_until,
 street_class,
 element_number,
 ST_Length
 (
  ST_Intersection
  (
   GeomFromEWKT('SRID=3068;POLYGON((24465.429 23673.364,24855.425 23673.364,24855.425 23393.704,24465.429 23393.704,24465.429 23673.364))'),
   soldner_segment
  )
 ) AS meters_length,
 ST_Intersection
 (
  GeomFromEWKT('SRID=3068;POLYGON((24465.429 23673.364,24855.425 23673.364,24855.425 23393.704,24465.429 23393.704,24465.429 23673.364))'),
  soldner_segment
 ) AS soldner_segment
FROM db_import.berlin_street_segments
WHERE
(
 ('1985-09-01' BETWEEN valid_since AND valid_until) AND
 ST_Intersects
 (
  GeomFromEWKT('SRID=3068;POLYGON((24465.429 23673.364,24855.425 23673.364,24855.425 23393.704,24465.429 23393.704,24465.429 23673.364))'),
  soldner_segment
 ) = 1
)
ORDER BY id_street,id_street_segment,valid_since,valid_until;
---------------
COMMIT;
---------------
SELECT DateTime('now'),'DETACH DATABASE ''../berlin_admin_geometries.db'' AS db_import';
DETACH DATABASE db_import;
SELECT DateTime('now'),'ATTACH DATABASE ''../../1989.mauerverlauf.db'' AS db_import';
ATTACH DATABASE '../1989.mauerverlauf.db' AS db_import;
BEGIN;
---------------
INSERT INTO berlin_polygons
 (id_geometry,id_admin,valid_since,valid_until,name,notes,
  soldner_polygon,soldner_linestring,soldner_ring,soldner_center,
  meters_area,meters_length,
  id_belongs_to,belongs_to,admin_level)
 SELECT
  id_geometry,id_admin,valid_since,valid_until,name,notes,
  CastToMultiPolygon(ST_Intersection
  (
   GeomFromEWKT('SRID=3068;POLYGON((24465.429 23673.364,24855.425 23673.364,24855.425 23393.704,24465.429 23393.704,24465.429 23673.364))'),
   soldner_polygon
  )) AS soldner_polygon,
  ST_Intersection
  (
   GeomFromEWKT('SRID=3068;POLYGON((24465.429 23673.364,24855.425 23673.364,24855.425 23393.704,24465.429 23393.704,24465.429 23673.364))'),
   soldner_linestring
  ) AS soldner_linestring,
  CastToMultiPolygon(ST_Intersection
  (
   GeomFromEWKT('SRID=3068;POLYGON((24465.429 23673.364,24855.425 23673.364,24855.425 23393.704,24465.429 23393.704,24465.429 23673.364))'),
   soldner_ring
  )) AS soldner_ring,
  ST_Centroid
  (
   ST_Intersection
   (
    GeomFromEWKT('SRID=3068;POLYGON((24465.429 23673.364,24855.425 23673.364,24855.425 23393.704,24465.429 23393.704,24465.429 23673.364))'),
    soldner_polygon
   )
  ) AS soldner_center,
  ST_Area
  (
   ST_Intersection
   (
    GeomFromEWKT('SRID=3068;POLYGON((24465.429 23673.364,24855.425 23673.364,24855.425 23393.704,24465.429 23393.704,24465.429 23673.364))'),
    soldner_polygon
   )
  ) AS meters_area,
  ST_Length
  (
   ST_Intersection
   (
    GeomFromEWKT('SRID=3068;POLYGON((24465.429 23673.364,24855.425 23673.364,24855.425 23393.704,24465.429 23393.704,24465.429 23673.364))'),
    soldner_linestring
   )
  ) AS meters_length,
  id_belongs_to,belongs_to,admin_level
 FROM db_import.berlin_polygons
 WHERE
( --  Areas between outer and inner borders, Grenzkommando
 (id_belongs_to IN (1937400000)) AND
 ((admin_level IN (430)) AND (changed_type IN (4))) AND
 ('1985-11-18' BETWEEN valid_since AND valid_until) AND
 ST_Intersects
 (
  GeomFromEWKT('SRID=3068;POLYGON((24465.429 23673.364,24855.425 23673.364,24855.425 23393.704,24465.429 23393.704,24465.429 23673.364))'),
  soldner_polygon
 ) = 1
)
ORDER BY id_admin,valid_since;
SELECT UpdateLayerStatistics();
COMMIT;
---------------
SELECT DateTime('now'),'DETACH DATABASE ''../1989.mauerverlauf.db'' AS db_import';
DETACH DATABASE db_import;
---------------
